import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common.js";
export declare namespace ITokenBundle {
    type TokenStruct = {
        assetContract: string;
        tokenType: BigNumberish;
        tokenId: BigNumberish;
        totalAmount: BigNumberish;
    };
    type TokenStructOutput = [string, number, BigNumber, BigNumber] & {
        assetContract: string;
        tokenType: number;
        tokenId: BigNumber;
        totalAmount: BigNumber;
    };
}
export interface IPackVRFDirectInterface extends utils.Interface {
    functions: {
        "canClaimRewards(address)": FunctionFragment;
        "claimRewards()": FunctionFragment;
        "createPack((address,uint8,uint256,uint256)[],uint256[],string,uint128,uint128,address)": FunctionFragment;
        "openPack(uint256,uint256)": FunctionFragment;
        "openPackAndClaimRewards(uint256,uint256,uint32)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "canClaimRewards" | "claimRewards" | "createPack" | "openPack" | "openPackAndClaimRewards"): FunctionFragment;
    encodeFunctionData(functionFragment: "canClaimRewards", values: [string]): string;
    encodeFunctionData(functionFragment: "claimRewards", values?: undefined): string;
    encodeFunctionData(functionFragment: "createPack", values: [
        ITokenBundle.TokenStruct[],
        BigNumberish[],
        string,
        BigNumberish,
        BigNumberish,
        string
    ]): string;
    encodeFunctionData(functionFragment: "openPack", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "openPackAndClaimRewards", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "canClaimRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "claimRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createPack", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "openPack", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "openPackAndClaimRewards", data: BytesLike): Result;
    events: {
        "PackCreated(uint256,address,uint256)": EventFragment;
        "PackOpenRequested(address,uint256,uint256,uint256)": EventFragment;
        "PackOpened(uint256,address,uint256,tuple[])": EventFragment;
        "PackRandomnessFulfilled(uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "PackCreated"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PackOpenRequested"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PackOpened"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PackRandomnessFulfilled"): EventFragment;
}
export interface PackCreatedEventObject {
    packId: BigNumber;
    recipient: string;
    totalPacksCreated: BigNumber;
}
export type PackCreatedEvent = TypedEvent<[
    BigNumber,
    string,
    BigNumber
], PackCreatedEventObject>;
export type PackCreatedEventFilter = TypedEventFilter<PackCreatedEvent>;
export interface PackOpenRequestedEventObject {
    opener: string;
    packId: BigNumber;
    amountToOpen: BigNumber;
    requestId: BigNumber;
}
export type PackOpenRequestedEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber
], PackOpenRequestedEventObject>;
export type PackOpenRequestedEventFilter = TypedEventFilter<PackOpenRequestedEvent>;
export interface PackOpenedEventObject {
    packId: BigNumber;
    opener: string;
    numOfPacksOpened: BigNumber;
    rewardUnitsDistributed: ITokenBundle.TokenStructOutput[];
}
export type PackOpenedEvent = TypedEvent<[
    BigNumber,
    string,
    BigNumber,
    ITokenBundle.TokenStructOutput[]
], PackOpenedEventObject>;
export type PackOpenedEventFilter = TypedEventFilter<PackOpenedEvent>;
export interface PackRandomnessFulfilledEventObject {
    packId: BigNumber;
    requestId: BigNumber;
}
export type PackRandomnessFulfilledEvent = TypedEvent<[
    BigNumber,
    BigNumber
], PackRandomnessFulfilledEventObject>;
export type PackRandomnessFulfilledEventFilter = TypedEventFilter<PackRandomnessFulfilledEvent>;
export interface IPackVRFDirect extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IPackVRFDirectInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        canClaimRewards(_opener: string, overrides?: CallOverrides): Promise<[boolean]>;
        claimRewards(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        createPack(contents: ITokenBundle.TokenStruct[], numOfRewardUnits: BigNumberish[], packUri: string, openStartTimestamp: BigNumberish, amountDistributedPerOpen: BigNumberish, recipient: string, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        openPack(packId: BigNumberish, amountToOpen: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        openPackAndClaimRewards(_packId: BigNumberish, _amountToOpen: BigNumberish, _callBackGasLimit: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    canClaimRewards(_opener: string, overrides?: CallOverrides): Promise<boolean>;
    claimRewards(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    createPack(contents: ITokenBundle.TokenStruct[], numOfRewardUnits: BigNumberish[], packUri: string, openStartTimestamp: BigNumberish, amountDistributedPerOpen: BigNumberish, recipient: string, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    openPack(packId: BigNumberish, amountToOpen: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    openPackAndClaimRewards(_packId: BigNumberish, _amountToOpen: BigNumberish, _callBackGasLimit: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        canClaimRewards(_opener: string, overrides?: CallOverrides): Promise<boolean>;
        claimRewards(overrides?: CallOverrides): Promise<ITokenBundle.TokenStructOutput[]>;
        createPack(contents: ITokenBundle.TokenStruct[], numOfRewardUnits: BigNumberish[], packUri: string, openStartTimestamp: BigNumberish, amountDistributedPerOpen: BigNumberish, recipient: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber
        ] & {
            packId: BigNumber;
            packTotalSupply: BigNumber;
        }>;
        openPack(packId: BigNumberish, amountToOpen: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        openPackAndClaimRewards(_packId: BigNumberish, _amountToOpen: BigNumberish, _callBackGasLimit: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {
        "PackCreated(uint256,address,uint256)"(packId?: BigNumberish | null, recipient?: null, totalPacksCreated?: null): PackCreatedEventFilter;
        PackCreated(packId?: BigNumberish | null, recipient?: null, totalPacksCreated?: null): PackCreatedEventFilter;
        "PackOpenRequested(address,uint256,uint256,uint256)"(opener?: string | null, packId?: BigNumberish | null, amountToOpen?: null, requestId?: null): PackOpenRequestedEventFilter;
        PackOpenRequested(opener?: string | null, packId?: BigNumberish | null, amountToOpen?: null, requestId?: null): PackOpenRequestedEventFilter;
        "PackOpened(uint256,address,uint256,tuple[])"(packId?: BigNumberish | null, opener?: string | null, numOfPacksOpened?: null, rewardUnitsDistributed?: null): PackOpenedEventFilter;
        PackOpened(packId?: BigNumberish | null, opener?: string | null, numOfPacksOpened?: null, rewardUnitsDistributed?: null): PackOpenedEventFilter;
        "PackRandomnessFulfilled(uint256,uint256)"(packId?: BigNumberish | null, requestId?: BigNumberish | null): PackRandomnessFulfilledEventFilter;
        PackRandomnessFulfilled(packId?: BigNumberish | null, requestId?: BigNumberish | null): PackRandomnessFulfilledEventFilter;
    };
    estimateGas: {
        canClaimRewards(_opener: string, overrides?: CallOverrides): Promise<BigNumber>;
        claimRewards(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        createPack(contents: ITokenBundle.TokenStruct[], numOfRewardUnits: BigNumberish[], packUri: string, openStartTimestamp: BigNumberish, amountDistributedPerOpen: BigNumberish, recipient: string, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        openPack(packId: BigNumberish, amountToOpen: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        openPackAndClaimRewards(_packId: BigNumberish, _amountToOpen: BigNumberish, _callBackGasLimit: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        canClaimRewards(_opener: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        claimRewards(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        createPack(contents: ITokenBundle.TokenStruct[], numOfRewardUnits: BigNumberish[], packUri: string, openStartTimestamp: BigNumberish, amountDistributedPerOpen: BigNumberish, recipient: string, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        openPack(packId: BigNumberish, amountToOpen: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        openPackAndClaimRewards(_packId: BigNumberish, _amountToOpen: BigNumberish, _callBackGasLimit: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=IPackVRFDirect.d.ts.map